# cs107-FinalProject
Final Project submission

Group 18

Members: Ethan Schumann, Alice Li, Ruizhe Kang, Vikram Shastry

[![codecov](https://codecov.io/gh/DERIVATORS/cs107-FinalProject/branch/master/graph/badge.svg?token=7EG4HFIWA6)](https://codecov.io/gh/DERIVATORS/cs107-FinalProject)

[![Build Status](https://travis-ci.com/travis-ci/travis-web.svg?branch=master)](https://travis-ci.com/travis-ci/travis-web)


## Broader Impact

This tool to perform automatic differentiation serves to help automate the calculation of derivatives and has potential to become more preferable to traditional calculation methods. As software developers and researchers, it is our duty to consider the possible positive and negative outcomes of sharing our software openly. Although the applications of derivative calculation tasks are vast, we can consider a few examples where certain applications may impact the society and day to day life. The maximization of functions in gradient descent methods require derivatives and the application of machine learning may be applied to real life tasks such as self-driving or the replacement of roles occupied traditionally by humans such as court judges. In both cases, the decisions of machine learning programs can have severe consequences for human lives. In self driving, the ethical implications could consider whether or not to prioritize the lives of passengers versus pedestrians in an accident. In court cases, the ethical implications involve whether or not to remove human biases by replacing human judges. 

## Software Inclusivity

Equally important is the need to address inclusivity for all software developers whether open source or in the workplace. There should not be any barriers at all to prevent other developers from contributing to our software package. Despite the availability of resources to freely share code like GitHub, recent surveys have shown that of the few (3%) women who responded, the majority (68%) wanted to contribute to open source but were less likely overall to do so. The lack of resources for younger developers and women in open source highlights the need for the more traditional male developers in open source to share a more open view towards diversity and mentorship. These barriers towards diversity are damaging to the tech industry as open-source projects are increasingly valued as evidence of skill for job hires. This package's development team demonstrated inclusivity in the course of this project. The development team consisted of persons of different genders, ages, ethnicities, family backgrounds, software experience, and educational backgrounds. The team included both full-time students and a full-time working professional. 
